@@ -139,128 +139,128 @@ const std::map<llvm::StringRef, hipCounter> CUDA_RAND_TYPE_NAME_MAP {
 };
 
 const std::map<llvm::StringRef, cudaAPIversions> CUDA_RAND_TYPE_NAME_VER_MAP {
-  {"CURAND_ORDERING_PSEUDO_LEGACY",                    {CUDA_110, CUDA_0,   CUDA_0, }}, // A: CUDA_VERSION 11001, CURAND_VERSION 10200, CURAND_VER_MAJOR 10 CURAND_VER_MINOR 2 CURAND_VER_PATCH 0
-  {"CURAND_ORDERING_PSEUDO_DYNAMIC",                   {CUDA_115, CUDA_0,   CUDA_0, }}, // A: CUDA_VERSION 11052, CURAND_VERSION 10207, CURAND_VER_MAJOR 10 CURAND_VER_MINOR 2 CURAND_VER_PATCH 7
+  {"CURAND_ORDERING_PSEUDO_LEGACY",                    {CUDA_110, CUDA_0,   CUDA_0  }}, // A: CUDA_VERSION 11001, CURAND_VERSION 10200, CURAND_VER_MAJOR 10 CURAND_VER_MINOR 2 CURAND_VER_PATCH 0
+  {"CURAND_ORDERING_PSEUDO_DYNAMIC",                   {CUDA_115, CUDA_0,   CUDA_0  }}, // A: CUDA_VERSION 11052, CURAND_VERSION 10207, CURAND_VER_MAJOR 10 CURAND_VER_MINOR 2 CURAND_VER_PATCH 7
 };
 
 const std::map<llvm::StringRef, hipAPIversions> HIP_RAND_TYPE_NAME_VER_MAP {
-  {"hiprandStatus",                                    {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandStatus_t",                                  {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandRngType_t",                                 {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandGenerator_st",                              {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandGenerator_t",                               {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandDiscreteDistribution_st",                   {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandDiscreteDistribution_t",                    {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandDirectionVectors32_t",                      {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandStateMtgp32",                               {HIP_1080, HIP_0,    HIP_0,  }},
-  {"hiprandStateMtgp32_t",                             {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandStateSobol32",                              {HIP_1080, HIP_0,    HIP_0,  }},
-  {"hiprandStateSobol32_t",                            {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandStateMRG32k3a",                             {HIP_1080, HIP_0,    HIP_0,  }},
-  {"hiprandStateMRG32k3a_t",                           {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandStatePhilox4_32_10",                        {HIP_1080, HIP_0,    HIP_0,  }},
-  {"hiprandStatePhilox4_32_10_t",                      {HIP_1080, HIP_0,    HIP_0,  }},
-  {"hiprandStateXORWOW",                               {HIP_1080, HIP_0,    HIP_0,  }},
-  {"hiprandStateXORWOW_t",                             {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandState",                                     {HIP_1080, HIP_0,    HIP_0,  }},
-  {"hiprandState_t",                                   {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_SUCCESS",                           {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_VERSION_MISMATCH",                  {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_NOT_INITIALIZED",                   {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_ALLOCATION_FAILED",                 {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_TYPE_ERROR",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_OUT_OF_RANGE",                      {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_LENGTH_NOT_MULTIPLE",               {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_DOUBLE_PRECISION_REQUIRED",         {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_LAUNCH_FAILURE",                    {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_PREEXISTING_FAILURE",               {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_INITIALIZATION_FAILED",             {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_ARCH_MISMATCH",                     {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_STATUS_INTERNAL_ERROR",                    {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_TEST",                                 {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_PSEUDO_DEFAULT",                       {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_PSEUDO_XORWOW",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_PSEUDO_MRG32K3A",                      {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_PSEUDO_MTGP32",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_PSEUDO_MT19937",                       {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_PSEUDO_PHILOX4_32_10",                 {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_QUASI_DEFAULT",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_QUASI_SOBOL32",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_QUASI_SCRAMBLED_SOBOL32",              {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_QUASI_SOBOL64",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"HIPRAND_RNG_QUASI_SCRAMBLED_SOBOL64",              {HIP_1050, HIP_0,    HIP_0,  }},
-  {"hiprandDirectionVectorSet_t",                      {HIP_6000, HIP_0,    HIP_0,  }},
-  {"HIPRAND_DIRECTION_VECTORS_32_JOEKUO6",             {HIP_6000, HIP_0,    HIP_0,  }},
-  {"HIPRAND_SCRAMBLED_DIRECTION_VECTORS_32_JOEKUO6",   {HIP_6000, HIP_0,    HIP_0,  }},
-  {"HIPRAND_DIRECTION_VECTORS_64_JOEKUO6",             {HIP_6000, HIP_0,    HIP_0,  }},
-  {"HIPRAND_SCRAMBLED_DIRECTION_VECTORS_64_JOEKUO6",   {HIP_6000, HIP_0,    HIP_0,  }},
-  {"hiprandDirectionVectors64_t",                      {HIP_6000, HIP_0,    HIP_0,  }},
-  {"hiprandOrdering",                                  {HIP_6020, HIP_0,    HIP_0,  }},
-  {"hiprandOrdering_t",                                {HIP_6020, HIP_0,    HIP_0,  }},
-  {"HIPRAND_ORDERING_PSEUDO_BEST",                     {HIP_6020, HIP_0,    HIP_0,  }},
-  {"HIPRAND_ORDERING_PSEUDO_DEFAULT",                  {HIP_6020, HIP_0,    HIP_0,  }},
-  {"HIPRAND_ORDERING_PSEUDO_SEEDED",                   {HIP_6020, HIP_0,    HIP_0,  }},
-  {"HIPRAND_ORDERING_PSEUDO_LEGACY",                   {HIP_6020, HIP_0,    HIP_0,  }},
-  {"HIPRAND_ORDERING_PSEUDO_DYNAMIC",                  {HIP_6020, HIP_0,    HIP_0,  }},
-  {"HIPRAND_ORDERING_QUASI_DEFAULT",                   {HIP_6020, HIP_0,    HIP_0,  }},
-  {"hiprandStateScrambledSobol32",                     {HIP_6020, HIP_0,    HIP_0,  }},
-  {"hiprandStateScrambledSobol32_t",                   {HIP_6020, HIP_0,    HIP_0,  }},
-  {"hiprandStateScrambledSobol64",                     {HIP_6020, HIP_0,    HIP_0,  }},
-  {"hiprandStateScrambledSobol64_t",                   {HIP_6020, HIP_0,    HIP_0,  }},
-  {"hiprandStateSobol64",                              {HIP_6020, HIP_0,    HIP_0,  }},
-  {"hiprandStateSobol64_t",                            {HIP_6020, HIP_0,    HIP_0,  }},
+  {"hiprandStatus",                                    {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandStatus_t",                                  {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandRngType_t",                                 {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandGenerator_st",                              {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandGenerator_t",                               {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandDiscreteDistribution_st",                   {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandDiscreteDistribution_t",                    {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandDirectionVectors32_t",                      {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandStateMtgp32",                               {HIP_1080, HIP_0,    HIP_0   }},
+  {"hiprandStateMtgp32_t",                             {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandStateSobol32",                              {HIP_1080, HIP_0,    HIP_0   }},
+  {"hiprandStateSobol32_t",                            {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandStateMRG32k3a",                             {HIP_1080, HIP_0,    HIP_0   }},
+  {"hiprandStateMRG32k3a_t",                           {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandStatePhilox4_32_10",                        {HIP_1080, HIP_0,    HIP_0   }},
+  {"hiprandStatePhilox4_32_10_t",                      {HIP_1080, HIP_0,    HIP_0   }},
+  {"hiprandStateXORWOW",                               {HIP_1080, HIP_0,    HIP_0   }},
+  {"hiprandStateXORWOW_t",                             {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandState",                                     {HIP_1080, HIP_0,    HIP_0   }},
+  {"hiprandState_t",                                   {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_SUCCESS",                           {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_VERSION_MISMATCH",                  {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_NOT_INITIALIZED",                   {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_ALLOCATION_FAILED",                 {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_TYPE_ERROR",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_OUT_OF_RANGE",                      {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_LENGTH_NOT_MULTIPLE",               {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_DOUBLE_PRECISION_REQUIRED",         {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_LAUNCH_FAILURE",                    {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_PREEXISTING_FAILURE",               {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_INITIALIZATION_FAILED",             {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_ARCH_MISMATCH",                     {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_STATUS_INTERNAL_ERROR",                    {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_TEST",                                 {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_PSEUDO_DEFAULT",                       {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_PSEUDO_XORWOW",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_PSEUDO_MRG32K3A",                      {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_PSEUDO_MTGP32",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_PSEUDO_MT19937",                       {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_PSEUDO_PHILOX4_32_10",                 {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_QUASI_DEFAULT",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_QUASI_SOBOL32",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_QUASI_SCRAMBLED_SOBOL32",              {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_QUASI_SOBOL64",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"HIPRAND_RNG_QUASI_SCRAMBLED_SOBOL64",              {HIP_1050, HIP_0,    HIP_0   }},
+  {"hiprandDirectionVectorSet_t",                      {HIP_6000, HIP_0,    HIP_0   }},
+  {"HIPRAND_DIRECTION_VECTORS_32_JOEKUO6",             {HIP_6000, HIP_0,    HIP_0   }},
+  {"HIPRAND_SCRAMBLED_DIRECTION_VECTORS_32_JOEKUO6",   {HIP_6000, HIP_0,    HIP_0   }},
+  {"HIPRAND_DIRECTION_VECTORS_64_JOEKUO6",             {HIP_6000, HIP_0,    HIP_0   }},
+  {"HIPRAND_SCRAMBLED_DIRECTION_VECTORS_64_JOEKUO6",   {HIP_6000, HIP_0,    HIP_0   }},
+  {"hiprandDirectionVectors64_t",                      {HIP_6000, HIP_0,    HIP_0   }},
+  {"hiprandOrdering",                                  {HIP_6020, HIP_0,    HIP_0   }},
+  {"hiprandOrdering_t",                                {HIP_6020, HIP_0,    HIP_0   }},
+  {"HIPRAND_ORDERING_PSEUDO_BEST",                     {HIP_6020, HIP_0,    HIP_0   }},
+  {"HIPRAND_ORDERING_PSEUDO_DEFAULT",                  {HIP_6020, HIP_0,    HIP_0   }},
+  {"HIPRAND_ORDERING_PSEUDO_SEEDED",                   {HIP_6020, HIP_0,    HIP_0   }},
+  {"HIPRAND_ORDERING_PSEUDO_LEGACY",                   {HIP_6020, HIP_0,    HIP_0   }},
+  {"HIPRAND_ORDERING_PSEUDO_DYNAMIC",                  {HIP_6020, HIP_0,    HIP_0   }},
+  {"HIPRAND_ORDERING_QUASI_DEFAULT",                   {HIP_6020, HIP_0,    HIP_0   }},
+  {"hiprandStateScrambledSobol32",                     {HIP_6020, HIP_0,    HIP_0   }},
+  {"hiprandStateScrambledSobol32_t",                   {HIP_6020, HIP_0,    HIP_0   }},
+  {"hiprandStateScrambledSobol64",                     {HIP_6020, HIP_0,    HIP_0   }},
+  {"hiprandStateScrambledSobol64_t",                   {HIP_6020, HIP_0,    HIP_0   }},
+  {"hiprandStateSobol64",                              {HIP_6020, HIP_0,    HIP_0   }},
+  {"hiprandStateSobol64_t",                            {HIP_6020, HIP_0,    HIP_0   }},
 
-  {"rocrand_status",                                   {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_STATUS_SUCCESS",                           {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_STATUS_VERSION_MISMATCH",                  {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_STATUS_NOT_CREATED",                       {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_STATUS_ALLOCATION_FAILED",                 {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_STATUS_TYPE_ERROR",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_STATUS_OUT_OF_RANGE",                      {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_STATUS_LENGTH_NOT_MULTIPLE",               {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_STATUS_DOUBLE_PRECISION_REQUIRED",         {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_STATUS_LAUNCH_FAILURE",                    {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_STATUS_INTERNAL_ERROR",                    {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_rng_type",                                 {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_PSEUDO_DEFAULT",                       {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_PSEUDO_XORWOW",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_PSEUDO_MRG32K3A",                      {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_PSEUDO_MTGP32",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_PSEUDO_MT19937",                       {HIP_5050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_PSEUDO_PHILOX4_32_10",                 {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_QUASI_DEFAULT",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_QUASI_SOBOL32",                        {HIP_1050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_QUASI_SCRAMBLED_SOBOL32",              {HIP_5040, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_QUASI_SOBOL64",                        {HIP_4050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_RNG_QUASI_SCRAMBLED_SOBOL64",              {HIP_5040, HIP_0,    HIP_0,  }},
-  {"rocrand_ordering",                                 {HIP_5050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_ORDERING_PSEUDO_BEST",                     {HIP_5050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_ORDERING_PSEUDO_DEFAULT",                  {HIP_5050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_ORDERING_PSEUDO_SEEDED",                   {HIP_5050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_ORDERING_PSEUDO_LEGACY",                   {HIP_5050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_ORDERING_PSEUDO_DYNAMIC",                  {HIP_5050, HIP_0,    HIP_0,  }},
-  {"ROCRAND_ORDERING_QUASI_DEFAULT",                   {HIP_5050, HIP_0,    HIP_0,  }},
-  {"rocrand_direction_vector_set",                     {HIP_6000, HIP_0,    HIP_0,  }},
-  {"ROCRAND_DIRECTION_VECTORS_32_JOEKUO6",             {HIP_6000, HIP_0,    HIP_0,  }},
-  {"ROCRAND_SCRAMBLED_DIRECTION_VECTORS_32_JOEKUO6",   {HIP_6000, HIP_0,    HIP_0,  }},
-  {"ROCRAND_DIRECTION_VECTORS_64_JOEKUO6",             {HIP_6000, HIP_0,    HIP_0,  }},
-  {"ROCRAND_SCRAMBLED_DIRECTION_VECTORS_64_JOEKUO6",   {HIP_6000, HIP_0,    HIP_0,  }},
-  {"rocrand_generator_base_type",                      {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_generator",                                {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_discrete_distribution_st",                 {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_discrete_distribution",                    {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_device::philox4x32_10_engine",             {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_state_philox4x32_10",                      {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_device::mtgp32_engine",                    {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_state_mtgp32",                             {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_device::scrambled_sobol32_engine<false>",  {HIP_5040, HIP_0,    HIP_0,  }},
-  {"rocrand_state_scrambled_sobol32",                  {HIP_5040, HIP_0,    HIP_0,  }},
-  {"rocrand_device::scrambled_sobol64_engine<false>",  {HIP_5040, HIP_0,    HIP_0,  }},
-  {"rocrand_state_scrambled_sobol64",                  {HIP_5040, HIP_0,    HIP_0,  }},
-  {"rocrand_device::sobol32_engine<false>",            {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_state_sobol32",                            {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_device::sobol64_engine<false>",            {HIP_4050, HIP_0,    HIP_0,  }},
-  {"rocrand_state_sobol64",                            {HIP_4050, HIP_0,    HIP_0,  }},
-  {"rocrand_device::mrg32k3a_engine",                  {HIP_1050, HIP_0,    HIP_0,  }},
-  {"rocrand_state_mrg32k3a",                           {HIP_1050, HIP_0,    HIP_0,  }},
+  {"rocrand_status",                                   {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_STATUS_SUCCESS",                           {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_STATUS_VERSION_MISMATCH",                  {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_STATUS_NOT_CREATED",                       {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_STATUS_ALLOCATION_FAILED",                 {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_STATUS_TYPE_ERROR",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_STATUS_OUT_OF_RANGE",                      {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_STATUS_LENGTH_NOT_MULTIPLE",               {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_STATUS_DOUBLE_PRECISION_REQUIRED",         {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_STATUS_LAUNCH_FAILURE",                    {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_STATUS_INTERNAL_ERROR",                    {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_rng_type",                                 {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_PSEUDO_DEFAULT",                       {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_PSEUDO_XORWOW",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_PSEUDO_MRG32K3A",                      {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_PSEUDO_MTGP32",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_PSEUDO_MT19937",                       {HIP_5050, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_PSEUDO_PHILOX4_32_10",                 {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_QUASI_DEFAULT",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_QUASI_SOBOL32",                        {HIP_1050, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_QUASI_SCRAMBLED_SOBOL32",              {HIP_5040, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_QUASI_SOBOL64",                        {HIP_4050, HIP_0,    HIP_0   }},
+  {"ROCRAND_RNG_QUASI_SCRAMBLED_SOBOL64",              {HIP_5040, HIP_0,    HIP_0   }},
+  {"rocrand_ordering",                                 {HIP_5050, HIP_0,    HIP_0   }},
+  {"ROCRAND_ORDERING_PSEUDO_BEST",                     {HIP_5050, HIP_0,    HIP_0   }},
+  {"ROCRAND_ORDERING_PSEUDO_DEFAULT",                  {HIP_5050, HIP_0,    HIP_0   }},
+  {"ROCRAND_ORDERING_PSEUDO_SEEDED",                   {HIP_5050, HIP_0,    HIP_0   }},
+  {"ROCRAND_ORDERING_PSEUDO_LEGACY",                   {HIP_5050, HIP_0,    HIP_0   }},
+  {"ROCRAND_ORDERING_PSEUDO_DYNAMIC",                  {HIP_5050, HIP_0,    HIP_0   }},
+  {"ROCRAND_ORDERING_QUASI_DEFAULT",                   {HIP_5050, HIP_0,    HIP_0   }},
+  {"rocrand_direction_vector_set",                     {HIP_6000, HIP_0,    HIP_0   }},
+  {"ROCRAND_DIRECTION_VECTORS_32_JOEKUO6",             {HIP_6000, HIP_0,    HIP_0   }},
+  {"ROCRAND_SCRAMBLED_DIRECTION_VECTORS_32_JOEKUO6",   {HIP_6000, HIP_0,    HIP_0   }},
+  {"ROCRAND_DIRECTION_VECTORS_64_JOEKUO6",             {HIP_6000, HIP_0,    HIP_0   }},
+  {"ROCRAND_SCRAMBLED_DIRECTION_VECTORS_64_JOEKUO6",   {HIP_6000, HIP_0,    HIP_0   }},
+  {"rocrand_generator_base_type",                      {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_generator",                                {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_discrete_distribution_st",                 {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_discrete_distribution",                    {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_device::philox4x32_10_engine",             {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_state_philox4x32_10",                      {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_device::mtgp32_engine",                    {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_state_mtgp32",                             {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_device::scrambled_sobol32_engine<false>",  {HIP_5040, HIP_0,    HIP_0   }},
+  {"rocrand_state_scrambled_sobol32",                  {HIP_5040, HIP_0,    HIP_0   }},
+  {"rocrand_device::scrambled_sobol64_engine<false>",  {HIP_5040, HIP_0,    HIP_0   }},
+  {"rocrand_state_scrambled_sobol64",                  {HIP_5040, HIP_0,    HIP_0   }},
+  {"rocrand_device::sobol32_engine<false>",            {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_state_sobol32",                            {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_device::sobol64_engine<false>",            {HIP_4050, HIP_0,    HIP_0   }},
+  {"rocrand_state_sobol64",                            {HIP_4050, HIP_0,    HIP_0   }},
+  {"rocrand_device::mrg32k3a_engine",                  {HIP_1050, HIP_0,    HIP_0   }},
+  {"rocrand_state_mrg32k3a",                           {HIP_1050, HIP_0,    HIP_0   }},
 };
