@@ -39,6 +39,7 @@ using namespace hipify;
 
 const std::string sHIP = "HIP";
 const std::string sROC = "ROC";
+const std::string sMIOPEN = "MIOPEN";
 const std::string sCub = "cub";
 const std::string sHipcub = "hipcub";
 const std::string sHIP_KERNEL_NAME = "HIP_KERNEL_NAME";
@@ -46,6 +47,7 @@ std::string sHIP_SYMBOL = "HIP_SYMBOL";
 std::string s_reinterpret_cast = "reinterpret_cast<const void*>";
 std::string s_reinterpret_cast_size_t = "reinterpret_cast<size_t*>";
 std::string s_static_cast_uint64_t = "static_cast<uint64_t>";
+std::string s_const_cast_char_pp = "const_cast<const char**>";
 std::string s_int32_t = "int32_t";
 std::string s_int64_t = "int64_t";
 const std::string sHipLaunchKernelGGL = "hipLaunchKernelGGL";
@@ -232,6 +234,8 @@ const std::string sCusparseSpMV_bufferSize = "cusparseSpMV_bufferSize";
 const std::string sCusparseSpMM_preprocess = "cusparseSpMM_preprocess";
 const std::string sCusparseSpSV_bufferSize = "cusparseSpSV_bufferSize";
 const std::string sCudaGetDriverEntryPoint = "cudaGetDriverEntryPoint";
+const std::string sNvrtcCompileProgram = "nvrtcCompileProgram";
+const std::string sNvrtcCreateProgram = "nvrtcCreateProgram";
 
 // CUDA_OVERLOADED
 const std::string sCudaEventCreate = "cudaEventCreate";
@@ -252,6 +256,7 @@ std::string getCastType(hipify::CastTypes c) {
     case e_HIP_SYMBOL: return sHIP_SYMBOL;
     case e_reinterpret_cast: return s_reinterpret_cast;
     case e_reinterpret_cast_size_t: return s_reinterpret_cast_size_t;
+    case e_const_cast_char_pp: return s_const_cast_char_pp;
     case e_static_cast_uint64_t: return s_static_cast_uint64_t;
     case e_int32_t: return s_int32_t;
     case e_int64_t: return s_int64_t;
@@ -290,6 +295,25 @@ std::map<std::string, hipify::FuncOverloadsStruct> FuncOverloads {
 };
 
 std::map<std::string, std::vector<ArgCastStruct>> FuncArgCasts {
+  {sNvrtcCompileProgram,
+    {
+      {
+        {
+          {2, {e_const_cast_char_pp, cw_None}}
+        }
+      }
+    }
+  },
+  {sNvrtcCreateProgram,
+    {
+      {
+        {
+          {4, {e_const_cast_char_pp, cw_None}},
+          {5, {e_const_cast_char_pp, cw_None}}
+        }
+      }
+    }
+  },
   {sCudaGetDriverEntryPoint,
     {
       {
@@ -2297,7 +2321,8 @@ void HipifyAction::FindAndReplace(StringRef name,
   if (Statistics::isHipExperimental(found->second) && !Experimental) {
     std::string sWarn;
     Statistics::isToRoc(found->second) ? sWarn = sROC : sWarn = sHIP;
-    sWarn = "" + sWarn;
+    if (Statistics::isToMIOpen(found->second))
+      sWarn = sMIOPEN;
     const auto ID = DE.getCustomDiagID(clang::DiagnosticsEngine::Warning, "'%0' is experimental in '%1'; to hipify it, use the '--experimental' option.");
     DE.Report(sl, ID) << found->first << sWarn;
     return;
@@ -2308,7 +2333,6 @@ void HipifyAction::FindAndReplace(StringRef name,
   if (Statistics::isHipSupportedV2Only(found->second) && found->second.apiType == API_BLAS && !insertedBLASHeader_V2) {
     std::string sWarn;
     Statistics::isToRoc(found->second) ? sWarn = sROC : sWarn = sHIP;
-    sWarn = "" + sWarn;
     const auto ID = DE.getCustomDiagID(clang::DiagnosticsEngine::Warning, "Only '%0_v2' version of '%0' is supported in '%1'; to hipify it, include 'cublas_v2.h' in the source.");
     DE.Report(sl, ID) << found->first << sWarn;
     return;
@@ -2317,7 +2341,8 @@ void HipifyAction::FindAndReplace(StringRef name,
   if (Statistics::isUnsupported(found->second)) {
     std::string sWarn;
     Statistics::isToRoc(found->second) ? sWarn = sROC : sWarn = sHIP;
-    sWarn = "" + sWarn;
+    if (Statistics::isToMIOpen(found->second))
+      sWarn = sMIOPEN;
     const auto ID = DE.getCustomDiagID(clang::DiagnosticsEngine::Warning, "'%0' is unsupported in '%1'.");
     DE.Report(sl, ID) << found->first << sWarn;
     return;
@@ -2492,6 +2517,8 @@ void HipifyAction::InclusionDirective(clang::SourceLocation hash_loc,
     clang::DiagnosticsEngine &DE = getCompilerInstance().getDiagnostics();
     std::string sWarn;
     Statistics::isToRoc(found->second) ? sWarn = sROC : sWarn = sHIP;
+    if (Statistics::isToMIOpen(found->second))
+      sWarn = sMIOPEN;
     const auto ID = DE.getCustomDiagID(clang::DiagnosticsEngine::Warning, "'%0' is unsupported header in '%1'.");
     DE.Report(sl, ID) << found->first << sWarn;
     return;
@@ -2682,7 +2709,10 @@ bool HipifyAction::cudaHostFuncCall(const mat::MatchFinder::MatchResult &Result)
     auto castStructs = it->second;
     auto &SM = *Result.SourceManager;
     for (auto cc : castStructs) {
-      if (cc.isToMIOpen != TranslateToMIOpen || cc.isToRoc != TranslateToRoc) continue;
+      if (TranslateToMIOpen == true && (cc.isToMIOpen == false && cc.isToRoc == false)) continue;
+      if (TranslateToMIOpen == false && cc.isToMIOpen == true) continue;
+      if (TranslateToRoc == true && cc.isToRoc == false) continue;
+      if (TranslateToRoc == false && cc.isToRoc == true && TranslateToMIOpen == false) continue;
       clang::LangOptions DefaultLangOptions;
       for (auto c : cc.castMap) {
         size_t length = 0;
@@ -2825,7 +2855,6 @@ bool HipifyAction::cudaOverloadedHostFuncCall(const mat::MatchFinder::MatchResul
     auto it = FuncOverloads.find(name);
     if (it == FuncOverloads.end()) return false;
     auto FuncOverloadsStruct = it->second;
-    if (FuncOverloadsStruct.isToMIOpen != TranslateToMIOpen || FuncOverloadsStruct.isToRoc != TranslateToRoc) return false;
     unsigned numArgs = call->getNumArgs();
     auto itNumArgs = FuncOverloadsStruct.overloadMap.find(numArgs);
     if (itNumArgs == FuncOverloadsStruct.overloadMap.end()) return false;
@@ -3106,7 +3135,9 @@ std::unique_ptr<clang::ASTConsumer> HipifyAction::CreateASTConsumer(clang::Compi
             sCusparseSpMV_bufferSize,
             sCusparseSpMM_preprocess,
             sCusparseSpSV_bufferSize,
-            sCudaGetDriverEntryPoint
+            sCudaGetDriverEntryPoint,
+            sNvrtcCompileProgram,
+            sNvrtcCreateProgram
           )
         )
       )
